@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  module: manages UDM modules
@@ -43,12 +42,11 @@ import re
 import shutil
 import tempfile
 import traceback
+from urllib.error import HTTPError, URLError
+from urllib.parse import quote, urlencode
+from urllib.request import Request
 
-import six
 from ldap import INVALID_CREDENTIALS, LDAPError
-from six.moves.urllib_error import HTTPError, URLError
-from six.moves.urllib_parse import quote, urlencode
-from six.moves.urllib_request import Request
 
 import univention.admin.modules as udm_modules
 import univention.admin.objects as udm_objects
@@ -113,7 +111,7 @@ def module_from_request(func):
 
 def bundled(func):
     def _decoarated(self, request):
-        bundled = isinstance(request.options, (list, tuple))
+        bundled = isinstance(request.options, list | tuple)
         if not bundled:
             ret = func(self, request)
         else:
@@ -154,12 +152,12 @@ class PropertySearchSanitizer(SearchSanitizer):
             # we get True/False as search value.
             # We need to make sure that the sanitizer rewrites this to the
             # correct thruthy/falsy string of the syntax class and not add asterisks.
-            if prop and issubclass(prop.syntax if inspect.isclass(prop.syntax) else type(prop.syntax), (udm_syntax.IStates, udm_syntax.boolean)):
+            if prop and issubclass(prop.syntax if inspect.isclass(prop.syntax) else type(prop.syntax), udm_syntax.IStates | udm_syntax.boolean):
                 self.use_asterisks = False
                 self.add_asterisks = False
                 value = prop.syntax.sanitize_property_search_value(value)
         try:
-            return super(PropertySearchSanitizer, self)._sanitize(value, name, further_arguments)
+            return super()._sanitize(value, name, further_arguments)
         finally:
             self.add_asterisks, self.use_asterisks = add_asterisks, use_asterisks
 
@@ -202,7 +200,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
         install_opener(ucr)
 
     def prepare(self, request):
-        super(Instance, self).prepare(request)
+        super().prepare(request)
         if not request.user_dn:
             raise UserWithoutDN(request.username)
 
@@ -220,15 +218,15 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
         self.modules_with_childs = container_modules()
 
     def set_locale(self, _locale):
-        super(Instance, self).set_locale(_locale)
+        super().set_locale(_locale)
         locale.setlocale(locale.LC_TIME, _locale)
 
     def error_handling(self, etype, exc, etraceback):
-        super(Instance, self).error_handling(etype, exc, etraceback)
-        if isinstance(exc, (udm_errors.authFail, INVALID_CREDENTIALS)):
+        super().error_handling(etype, exc, etraceback)
+        if isinstance(exc, udm_errors.authFail | INVALID_CREDENTIALS):
             MODULE.warn('Authentication failed: %s' % (exc,))
             raise LDAP_AuthenticationFailed()
-        if isinstance(exc, (udm_errors.base, LDAPError)):
+        if isinstance(exc, udm_errors.base | LDAPError):
             MODULE.error(''.join(traceback.format_exception(etype, exc, etraceback)))
 
     def require_license(self, lo):
@@ -303,7 +301,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
                     license_data[item] = {}
                     for lic_type in ('CLIENT', 'ACCOUNT', 'DESKTOP', 'GROUPWARE'):
                         count = getattr(udm_license._license, item)[udm_license._license.version][getattr(udm_license.License, lic_type)]
-                        if isinstance(count, six.string_types):
+                        if isinstance(count, str):
                             try:
                                 count = int(count)
                             except ValueError:
@@ -317,7 +315,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
                     license_data[item] = {}
                     for lic_type in ('SERVERS', 'USERS', 'MANAGEDCLIENTS', 'CORPORATECLIENTS'):
                         count = getattr(udm_license._license, item)[udm_license._license.version][getattr(udm_license.License, lic_type)]
-                        if isinstance(count, six.string_types):
+                        if isinstance(count, str):
                             try:
                                 count = int(count)
                             except ValueError:
@@ -347,7 +345,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
     @LDAP_Connection
     def license_import(self, request, ldap_connection=None, ldap_position=None):
         filename = None
-        if isinstance(request.options, (list, tuple)) and request.options:
+        if isinstance(request.options, list | tuple) and request.options:
             # file upload
             file_upload(lambda s, r: None)(self, request)  # protect against hacking attempts!
             filename = request.options[0]['tmpfile']
@@ -357,7 +355,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
 
             # Replace non-breaking space with a normal space
             # https://forge.univention.org/bugzilla/show_bug.cgi?id=30098
-            lic = lic.replace(u'\xa0', " ")
+            lic = lic.replace('\xa0', " ")
 
             lic_file = tempfile.NamedTemporaryFile(delete=False)
             lic_file.write(lic.encode('UTF-8'))
@@ -714,7 +712,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
         try:
             with open(filename, 'rb') as fd:
                 self.finished(request.id, fd.read(), mimetype='text/csv' if report.endswith('.csv') else 'application/pdf')
-        except EnvironmentError:
+        except OSError:
             raise UMC_Error(_('The report does not exists. Please create a new one.'), status=404)
 
     def values(self, request):
@@ -946,7 +944,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
                 raise UMC_Error(_('Property %s not found') % property_name)
 
             # check each element if 'value' is a list
-            if isinstance(value, (tuple, list)) and property_obj.multivalue:
+            if isinstance(value, tuple | list) and property_obj.multivalue:
                 subResults = []
                 subDetails = []
                 for ival in value:
@@ -1276,7 +1274,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
             infos = copy.copy(policy_obj.polinfo_more)
             for key in infos.keys():
                 if key in policy_obj.polinfo:
-                    if isinstance(infos[key], (tuple, list)):
+                    if isinstance(infos[key], tuple | list):
                         continue
                     infos[key]['value'] = policy_obj.polinfo[key]
 
@@ -1312,7 +1310,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
         data['licence'] = license
         data = urlencode(data).encode('ASCII')
         url = 'https://license.univention.de/keyid/conversion/submit'
-        request = Request(url, data=data, headers={'User-agent': 'UMC/AppCenter'})
+        request = Request(url, data=data, headers={'User-agent': 'UMC/AppCenter'})  # noqa: S310
         self._request_license(request)
         # creating a new ucr variable to prevent duplicated registration (Bug #35711)
         handler_set(['ucs/web/license/requested=true'])
@@ -1321,7 +1319,7 @@ class Instance(Base, ProgressMixin, metaclass=UDMModuleMeta):
     def _request_license(self, request):
         try:
             urlopen(request)
-        except (HTTPError, URLError, IOError) as exc:
+        except (OSError, HTTPError, URLError) as exc:
             strerror = ''
             if hasattr(exc, 'read'):  # try to parse an html error
                 body = exc.read().decode('UTF-8', 'replace')
